Stan Math Library: stan/math/prim/mat/fun/factor_U.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
factor_U.hpp File Reference
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/prim/scal/fun/constants.hpp>`
`#include <cmath>`
`#include <cstddef>`
`#include <iostream>`
`#include <limits>`
`#include <stdexcept>`
`#include <sstream>`
`#include <vector>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T >
void | stan::math::factor_U (const Eigen::Matrix< T, Eigen::Dynamic, Eigen::Dynamic > &U, Eigen::Array< T, Eigen::Dynamic, 1 > &CPCs)
| This function is intended to make starting values, given a unit upper-triangular matrix U such that U'DU is a correlation matrix. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.